Crate lncat

Crate lncat 

Utils used to create a cat like command

Here I implemented a Config struct to set the configs and a function called run to consume that struct.

Structs

Config
This struct contains all file paths to be concatenated

Functions

run
The function run takes a Config as the input and concatenates all the files in it